==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'URL на сайта', # MODIF
	'form_pet_aucune_signature' => 'Кодът не отговаря на никой запис', # MODIF
	'form_pet_confirmation' => 'Моля, потвърдете записа:',
	'form_pet_deja_signe' => 'Тектът вече е записан.',
	'form_pet_envoi_mail_confirmation' => 'Писмо за потвърждение вече е изпратено до Вас. Моля, посетете уеб-адреса, споменат в това писмо, за да потвърдите записа си. ', # MODIF
	'form_pet_mail_confirmation' => 'Добър ден,

Пожелали сте да подпишете молбата:
@titre@.

Подали сте следната информация:
    Име: @nom_email@
    Сайт: @nom_site@ - @url_site@
@message@

ВАЖНО!
За да потвърдите записа, посетете следния 
Интернет адрес (в противен случай молбата
ще бъде отхвърлена):
    @url@

Благодаря за участието!
',
	'form_pet_nom_site2' => 'Име на Вашия сайт', # MODIF
	'form_pet_probleme_technique' => 'Техническа грешка: записите са прекъснати моментално.',
	'form_pet_signature_validee' => 'Подписът е одобрен. Благодаря!',
	'form_pet_site_deja_enregistre' => 'Сайтът е вече регистриран',
	'form_pet_url_invalide' => 'Грешен уеб-адрес (URL) на страницата',
	'form_pet_votre_email' => 'Електронен адрес',
	'form_pet_votre_nom' => 'Име или псевдоним', # MODIF
	'form_pet_votre_site' => 'Ако имате Интернет страница, може да я отворите по-долу',

	// I
	'info_adresse_email' => 'ЕЛЕКТРОНЕН АДРЕС:',
	'info_site_web' => 'ИНТЕРНЕТ САЙТ:',

	// L
	'lien_reponse_article' => 'Отговор на статията'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Активиране на молбата',
	'bouton_radio_pas_petition' => 'Без молба',
	'bouton_radio_petition_activee' => 'Молбата е активирана',
	'bouton_radio_supprimer_petition' => 'Изтриване на молбата',

	// F
	'form_pet_adresse_site' => 'URL на сайта', # MODIF
	'form_pet_aucune_signature' => 'Кодът не отговаря на никой запис', # MODIF
	'form_pet_confirmation' => 'Моля, потвърдете записа:',
	'form_pet_deja_signe' => 'Тектът вече е записан.',
	'form_pet_envoi_mail_confirmation' => 'Писмо за потвърждение вече е изпратено до Вас. Моля, посетете уеб-адреса, споменат в това писмо, за да потвърдите записа си. ', # MODIF
	'form_pet_mail_confirmation' => 'Добър ден,

Пожелали сте да подпишете молбата:
@titre@.

Подали сте следната информация:
    Име: @nom_email@
    Сайт: @nom_site@ - @url_site@
@message@

ВАЖНО!
За да потвърдите записа, посетете следния 
Интернет адрес (в противен случай молбата
ще бъде отхвърлена):
    @url@

Благодаря за участието!
',
	'form_pet_nom_site2' => 'Име на Вашия сайт', # MODIF
	'form_pet_probleme_technique' => 'Техническа грешка: записите са прекъснати моментално.',
	'form_pet_signature_validee' => 'Подписът е одобрен. Благодаря!',
	'form_pet_site_deja_enregistre' => 'Сайтът е вече регистриран',
	'form_pet_url_invalide' => 'Грешен уеб-адрес (URL) на страницата',
	'form_pet_votre_email' => 'Електронен адрес',
	'form_pet_votre_nom' => 'Име или псевдоним', # MODIF
	'form_pet_votre_site' => 'Ако имате Интернет страница, може да я отворите по-долу',

	// I
	'info_adresse_email' => 'ЕЛЕКТРОНЕН АДРЕС:',
	'info_site_web' => 'ИНТЕРНЕТ САЙТ:',

	// L
	'lien_reponse_article' => 'Отговор на статията'
);

?>
